@@ -1,7 +1,6 @@
-import sqlsoup
+from . import sqlsoup
 from sqlalchemy import Table, util
 
-
 class Genome(sqlsoup.SQLSoup):
 
     def map_to(self, attrname, tablename=None, selectable=None,
@@ -13,6 +12,9 @@ class Genome(sqlsoup.SQLSoup):
         pids = [x for x in tbl.columns if x.name in ('chrom', 'chromStart', 'name',
                                                           'txStart', 'kgID')
                                        or x.primary_key or x.unique]
+        if pids == []:
+            pids = [x for x in tbl.columns if any(c in x.name.lower() for c in
+                'chrom start name'.split())]
         models = __import__("cruzdb.models", globals(), locals(), [], -1).models
         try:
             base = getattr(models, tablename)
@@ -27,6 +29,6 @@ class Genome(sqlsoup.SQLSoup):
 if __name__ == "__main__":
     db = Genome('mysql://genome@genome-mysql.cse.ucsc.edu/hg19')
 
-    print db.cpgIslandExt.first()
-    print db.refGene.first()
+    print(db.cpgIslandExt.first())
+    print(db.refGene.first())
 
